@@ -10,8 +10,8 @@ my $file = 't/sample.data';
 my %p = (
     file => $file, 
     #engine => 'objects',
-    pre_filter => ['subs', 'objects'],
-    pre_filter_dump => 2,
+    post_proc => ['subs', 'objects'],
+    post_proc_dump => 2,
 );
 
 my $des = Devel::Examine::Subs->new(%p);
