@@ -15,9 +15,9 @@ my %params = (
 #                pre_proc => ,
 #                pre_proc_return => 1,
 #                pre_proc_dump => 1,
-                pre_filter => 'file_lines_contain',
-#                pre_filter_dump => 1,
-#                pre_filter_return => 1,
+                post_proc => 'file_lines_contain',
+#                post_proc_dump => 1,
+#                post_proc_return => 1,
                 engine => new_has(),
 #                engine_return => 1,
 #                engine_dump => 1,
